# Provision Namespace Ceremony SD Card

## Requirements

* Personal PGP Keys

* SD Card Booster Pack

## Procedure

1. Plug in a fresh formatted SD card into the computer

1. Create a directory called `public_certificates` on the SD card

1. Copy the desired OpenPGP public certificates you wish to shard to during the ceremony into the `public_certificates` directory on the SD card. The number of public certificates in this directory corresponds to the `N` value in a `M of N` quorum.

1. Write the following script to a file called `ceremony.sh`

    * `<threshold_value>` should be replaced with the desired `M` value in a `M of N` quorum

    * If you would like to generate an OpenPGP public certificate, add `--output-cert /media/cert` and `--user-id <name>` to the command

    ```sh
    #!/bin/sh

    script_dir="$(dirname "$(realpath "$0")")"

    read -p "Provide the path to PGP certificates which will be used for the ceremony: " relative_path

    directory_path="$script_dir/$relative_path"

    if [ ! -d "$directory_path" ]; then
        echo "Directory does not exist. Please enter a valid directory path."
        exit 1
    fi

    for file in "$directory_path"/*; do
    if [ -f "$file" ]; then
        echo "Processing file: $file"
        gpg --import --import-options import-show $file
    fi
    done

    read -p "Do the PGP key IDs match what you expect? (y/n): " matches_expectation

    if [ $matches_expectation != "y" ]; then
        echo "Ceasing ceremony as PGP key IDs don't match"
        exit 1
    fi

    keyfork bottoms-up --threshold <threshold_value> --output-shardfile /media/shardfile /media/public-certificates/
    ```

1. Write the `ceremony.sh` script to the SD card

1. Burn the SD card contents to the SD card using `sdtool`

{{ #include ../../../../sdtool-instructions.md:steps }}

1. Label the SD card "Namespace Ceremony [date]"

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-sealing }}